Method: ActiveSupport::CoreExtensions::String::Inflections#classify

Defined in:
lib/active_support/core_ext/string/inflections.rb

#classifyObject

Create a class name from a plural table name like Rails does for table names to models. Note that this returns a string and not a class. (To convert to an actual class follow classify with constantize.)

"egg_and_hams".classify # => "EggAndHam"
"posts".classify        # => "Post"

Singular names are not handled correctly.

"business".classify # => "Busines"


129
130
131
# File 'lib/active_support/core_ext/string/inflections.rb', line 129

def classify
  Inflector.classify(self)
end